import { HttpClient, HttpClientResponse } from './network/HttpClient.js';
import { DBRecordsBatchDraft, Model, type DBRecord, DBRecordInstance, DBRecordDraft, DBRecordsArrayInstance, Transaction, EmptyTargetError, NonUniqueResultError, UniquenessError, idToDate, idToTimestamp, type Relation, type InferType, type UserProvidedConfig } from './sdk/index.js';
import { type ApiResponse, RestAPI } from './api/index.js';
declare const RushDB: {
    new (token?: string, config?: UserProvidedConfig): {
        state: import("./sdk/types.js").State;
        models: Map<string, Model>;
        registerModel(model: Model): Model<any>;
        getModels(): Map<string, Model>;
        getModel<Label extends keyof import("./types/query.js").Models | string = never>(label: Label): Label extends keyof import("./types/query.js").Models ? Model<import("./types/query.js").Models[Label]> : Model | undefined;
        toInstance<S extends import("./types/schema.js").Schema = import("./types/schema.js").Schema>(record: import("./types/utils.js").FlattenTypes<{
            readonly __id: string;
            readonly __label: string;
            readonly __proptypes?: import("./types/utils.js").FlattenTypes<{ [Key in import("./types/schema.js").RequiredKeysRead<S>]: S[Key]["type"]; } & { [Key_1 in import("./types/schema.js").OptionalKeysRead<S>]?: S[Key_1]["type"] | undefined; }> | undefined;
        } & import("./types/utils.js").FlattenTypes<import("./sdk/record.js").RecordProps<S>>>): DBRecordInstance<S, import("./types/query.js").SearchQuery<S>>;
        api: ReturnType<typeof import("./api/create-api.js").createApi>;
        fetcher: ReturnType<typeof import("./network/index.js").createFetcher>;
        records: import("./api/types.js").RecordsApi;
        relations: {
            find: <S extends import("./types/schema.js").Schema = any>({ pagination, search, transaction }: {
                pagination?: Pick<import("./types/query.js").SearchQuery, "limit" | "skip">;
                search?: import("./types/query.js").SearchQuery<S> | undefined;
                transaction?: Transaction | string;
            }) => Promise<ApiResponse<Relation[]>>;
        };
        properties: {
            delete: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property>>;
            find: <S extends import("./types/schema.js").Schema = any>(searchParams: import("./types/query.js").SearchQuery<S>, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property[]>>;
            findById: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property>>;
            values: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property & import("./types/value.js").PropertyValuesData>>;
        };
        labels: {
            find: <S extends import("./types/schema.js").Schema = any>(searchParams: import("./types/query.js").SearchQuery<S>, transaction?: Transaction | string) => Promise<ApiResponse<Record<string, number>>>;
        };
        tx: {
            begin: (config?: Partial<{
                ttl: number;
            }>) => Promise<Transaction>;
            commit: (id: string) => Promise<ApiResponse<{
                message: string;
            }>>;
            get: (id: string) => Promise<Transaction>;
            rollback: (id: string) => Promise<ApiResponse<{
                message: string;
            }>>;
        };
    };
    instance: {
        state: import("./sdk/types.js").State;
        models: Map<string, Model>;
        registerModel(model: Model): Model<any>;
        getModels(): Map<string, Model>;
        getModel<Label extends keyof import("./types/query.js").Models | string = never>(label: Label): Label extends keyof import("./types/query.js").Models ? Model<import("./types/query.js").Models[Label]> : Model | undefined;
        toInstance<S extends import("./types/schema.js").Schema = import("./types/schema.js").Schema>(record: import("./types/utils.js").FlattenTypes<{
            readonly __id: string;
            readonly __label: string;
            readonly __proptypes?: import("./types/utils.js").FlattenTypes<{ [Key in import("./types/schema.js").RequiredKeysRead<S>]: S[Key]["type"]; } & { [Key_1 in import("./types/schema.js").OptionalKeysRead<S>]?: S[Key_1]["type"] | undefined; }> | undefined;
        } & import("./types/utils.js").FlattenTypes<import("./sdk/record.js").RecordProps<S>>>): DBRecordInstance<S, import("./types/query.js").SearchQuery<S>>;
        api: ReturnType<typeof import("./api/create-api.js").createApi>;
        fetcher: ReturnType<typeof import("./network/index.js").createFetcher>;
        records: import("./api/types.js").RecordsApi;
        relations: {
            find: <S extends import("./types/schema.js").Schema = any>({ pagination, search, transaction }: {
                pagination?: Pick<import("./types/query.js").SearchQuery, "limit" | "skip">;
                search?: import("./types/query.js").SearchQuery<S> | undefined;
                transaction?: Transaction | string;
            }) => Promise<ApiResponse<Relation[]>>;
        };
        properties: {
            delete: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property>>;
            find: <S extends import("./types/schema.js").Schema = any>(searchParams: import("./types/query.js").SearchQuery<S>, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property[]>>;
            findById: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property>>;
            values: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property & import("./types/value.js").PropertyValuesData>>;
        };
        labels: {
            find: <S extends import("./types/schema.js").Schema = any>(searchParams: import("./types/query.js").SearchQuery<S>, transaction?: Transaction | string) => Promise<ApiResponse<Record<string, number>>>;
        };
        tx: {
            begin: (config?: Partial<{
                ttl: number;
            }>) => Promise<Transaction>;
            commit: (id: string) => Promise<ApiResponse<{
                message: string;
            }>>;
            get: (id: string) => Promise<Transaction>;
            rollback: (id: string) => Promise<ApiResponse<{
                message: string;
            }>>;
        };
    };
    getInstance(): {
        state: import("./sdk/types.js").State;
        models: Map<string, Model>;
        registerModel(model: Model): Model<any>;
        getModels(): Map<string, Model>;
        getModel<Label extends keyof import("./types/query.js").Models | string = never>(label: Label): Label extends keyof import("./types/query.js").Models ? Model<import("./types/query.js").Models[Label]> : Model | undefined;
        toInstance<S extends import("./types/schema.js").Schema = import("./types/schema.js").Schema>(record: import("./types/utils.js").FlattenTypes<{
            readonly __id: string;
            readonly __label: string;
            readonly __proptypes?: import("./types/utils.js").FlattenTypes<{ [Key in import("./types/schema.js").RequiredKeysRead<S>]: S[Key]["type"]; } & { [Key_1 in import("./types/schema.js").OptionalKeysRead<S>]?: S[Key_1]["type"] | undefined; }> | undefined;
        } & import("./types/utils.js").FlattenTypes<import("./sdk/record.js").RecordProps<S>>>): DBRecordInstance<S, import("./types/query.js").SearchQuery<S>>;
        api: ReturnType<typeof import("./api/create-api.js").createApi>;
        fetcher: ReturnType<typeof import("./network/index.js").createFetcher>;
        records: import("./api/types.js").RecordsApi;
        relations: {
            find: <S extends import("./types/schema.js").Schema = any>({ pagination, search, transaction }: {
                pagination?: Pick<import("./types/query.js").SearchQuery, "limit" | "skip">;
                search?: import("./types/query.js").SearchQuery<S> | undefined;
                transaction?: Transaction | string;
            }) => Promise<ApiResponse<Relation[]>>;
        };
        properties: {
            delete: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property>>;
            find: <S extends import("./types/schema.js").Schema = any>(searchParams: import("./types/query.js").SearchQuery<S>, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property[]>>;
            findById: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property>>;
            values: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("./types/value.js").Property & import("./types/value.js").PropertyValuesData>>;
        };
        labels: {
            find: <S extends import("./types/schema.js").Schema = any>(searchParams: import("./types/query.js").SearchQuery<S>, transaction?: Transaction | string) => Promise<ApiResponse<Record<string, number>>>;
        };
        tx: {
            begin: (config?: Partial<{
                ttl: number;
            }>) => Promise<Transaction>;
            commit: (id: string) => Promise<ApiResponse<{
                message: string;
            }>>;
            get: (id: string) => Promise<Transaction>;
            rollback: (id: string) => Promise<ApiResponse<{
                message: string;
            }>>;
        };
    };
};
export { RushDB, DBRecordsBatchDraft, DBRecordDraft, UserProvidedConfig, Model, type DBRecord, type Relation, DBRecordInstance, DBRecordsArrayInstance, Transaction, EmptyTargetError, HttpClient, HttpClientResponse, NonUniqueResultError, UniquenessError, RestAPI, type InferType, type ApiResponse, idToDate, idToTimestamp };
export * from './types/index.js';
export default RushDB;
