import type { SearchQuery, Schema, FlattenTypes, InferSchemaTypesRead, InferSchemaTypesWrite, MaybeArray } from '../types/index.js';
import type { DBRecord, DBRecordInstance, DBRecordsArrayInstance, RelationDetachOptions, RelationOptions, RelationTarget } from './record.js';
import type { Transaction } from './transaction.js';
import { RestApiProxy } from '../api/rest-api-proxy.js';
type RushDBInstance = {
    registerModel(model: Model): void;
};
export declare class Model<S extends Schema = any> extends RestApiProxy {
    readonly label: string;
    readonly schema: S;
    constructor(modelName: string, schema: S, RushDBInstance?: RushDBInstance);
    /** @description
     * Type helper for a draft version of the schema.
     * Represents a flat object containing only the record's own properties
     * (defined by the schema), excluding system fields such as `__id`, `__label`,
     * and `__proptypes`. This type does not yet have a representation on the
     * database side.
     */
    readonly draft: InferType<Model<S>>;
    /** @description
     * Type helper for a fully-defined record with database representation.
     * Similar to the draft, but includes all fields that come with the record's
     * database-side representation, such as `__id`, `__label`, and `__proptypes`.
     */
    readonly record: DBRecord<S>;
    /** @description
     * Type helper for a single record instance.
     * Extends the record by providing additional methods to operate on this specific
     * record, such as saving, updating, or deleting it.
     */
    readonly recordInstance: DBRecordInstance<S>;
    /** @description
     * Type helper for an array of record instances.
     * Similar to a single record instance but supports batch or bulk operations,
     * allowing efficient management of multiple records simultaneously.
     */
    readonly recordsArrayInstance: DBRecordsArrayInstance<S>;
    getLabel(): string;
    find<Q extends SearchQuery<S> = SearchQuery<S>>(params?: Q & {
        labels?: never;
    }, transaction?: Transaction | string): Promise<DBRecordsArrayInstance<S, Q>>;
    findOne<Q extends SearchQuery<S> = SearchQuery<S>>(params?: Q & {
        labels?: never;
        limit?: never;
        skip?: never;
    }, transaction?: Transaction | string): Promise<DBRecordInstance<S, Q>>;
    findById(id: string, transaction?: Transaction | string): Promise<DBRecordInstance<S, {
        where: {
            $id: string;
        };
    }>>;
    findUniq<Q extends SearchQuery<S> = SearchQuery<S>>(params?: Q & {
        labels?: never;
        limit?: never;
        skip?: never;
    }, transaction?: Transaction | string): Promise<DBRecordInstance<S, Q>>;
    create(record: InferSchemaTypesWrite<S>, transaction?: Transaction | string): Promise<DBRecordInstance<S, SearchQuery<S>>>;
    attach(sourceId: string, target: RelationTarget, options?: RelationOptions, transaction?: Transaction | string): Promise<import("../index.node.js").ApiResponse<{
        message: string;
    }, Record<string, any>>>;
    detach(sourceId: string, target: RelationTarget, options?: RelationDetachOptions, transaction?: Transaction | string): Promise<import("../index.node.js").ApiResponse<{
        message: string;
    }, Record<string, any>>>;
    private handleSetOrUpdate;
    set(id: string, record: InferSchemaTypesWrite<S>, transaction?: Transaction | string): Promise<DBRecordInstance<S, SearchQuery<S>>>;
    update(id: string, record: Partial<InferSchemaTypesWrite<S>>, transaction?: Transaction | string): Promise<DBRecordInstance<S, SearchQuery<S>>>;
    createMany(records: InferSchemaTypesWrite<S>[], transaction?: Transaction | string): Promise<DBRecordsArrayInstance<S, SearchQuery<S>>>;
    delete(searchParams: Omit<SearchQuery<S>, 'labels'>, transaction?: Transaction | string): Promise<import("../index.node.js").ApiResponse<{
        message: string;
    }, Record<string, any>>>;
    deleteById(idOrIds: MaybeArray<string>, transaction?: Transaction | string): Promise<import("../index.node.js").ApiResponse<{
        message: string;
    }, Record<string, any>>>;
}
export type InferType<M extends Model<any> = Model<any>> = FlattenTypes<InferSchemaTypesRead<M['schema']>>;
export {};
