import type { HttpClient } from '../network/HttpClient.js';
import type { Models, Schema } from '../types/index.js';
import type { Model } from './model.js';
import type { State, UserProvidedConfig } from './types.js';
import { DBRecordInstance } from './record.js';
export declare const initSDK: (httpClient: HttpClient) => {
    new (token?: string, config?: UserProvidedConfig): {
        state: State;
        models: Map<string, Model>;
        registerModel(model: Model): Model<any>;
        getModels(): Map<string, Model>;
        getModel<Label extends keyof Models | string = never>(label: Label): Label extends keyof Models ? Model<Models[Label]> : Model | undefined;
        toInstance<S extends Schema = Schema>(record: import("../types/utils.js").FlattenTypes<{
            readonly __id: string;
            readonly __label: string;
            readonly __proptypes?: import("../types/utils.js").FlattenTypes<{ [Key in import("../types/schema.js").RequiredKeysRead<S>]: S[Key]["type"]; } & { [Key_1 in import("../types/schema.js").OptionalKeysRead<S>]?: S[Key_1]["type"] | undefined; }> | undefined;
        } & import("../types/utils.js").FlattenTypes<import("./record.js").RecordProps<S>>>): DBRecordInstance<S, import("../types/query.js").SearchQuery<S>>;
        api: ReturnType<typeof import("../api/create-api.js").createApi>;
        fetcher: ReturnType<typeof import("../network/index.js").createFetcher>;
        records: import("../api/types.js").RecordsApi;
        relations: {
            find: <S extends Schema = any>({ pagination, search, transaction }: {
                pagination?: Pick<import("../types/query.js").SearchQuery, "limit" | "skip">;
                search?: import("../types/query.js").SearchQuery<S> | undefined;
                transaction?: import("./transaction.js").Transaction | string;
            }) => Promise<import("../index.node.js").ApiResponse<import("./record.js").Relation[]>>;
        };
        properties: {
            delete: (id: string, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property>>;
            find: <S extends Schema = any>(searchParams: import("../types/query.js").SearchQuery<S>, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property[]>>;
            findById: (id: string, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property>>;
            values: (id: string, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property & import("../types/value.js").PropertyValuesData>>;
        };
        labels: {
            find: <S extends Schema = any>(searchParams: import("../types/query.js").SearchQuery<S>, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<Record<string, number>>>;
        };
        tx: {
            begin: (config?: Partial<{
                ttl: number;
            }>) => Promise<import("./transaction.js").Transaction>;
            commit: (id: string) => Promise<import("../index.node.js").ApiResponse<{
                message: string;
            }>>;
            get: (id: string) => Promise<import("./transaction.js").Transaction>;
            rollback: (id: string) => Promise<import("../index.node.js").ApiResponse<{
                message: string;
            }>>;
        };
    };
    instance: {
        state: State;
        models: Map<string, Model>;
        registerModel(model: Model): Model<any>;
        getModels(): Map<string, Model>;
        getModel<Label extends keyof Models | string = never>(label: Label): Label extends keyof Models ? Model<Models[Label]> : Model | undefined;
        toInstance<S extends Schema = Schema>(record: import("../types/utils.js").FlattenTypes<{
            readonly __id: string;
            readonly __label: string;
            readonly __proptypes?: import("../types/utils.js").FlattenTypes<{ [Key in import("../types/schema.js").RequiredKeysRead<S>]: S[Key]["type"]; } & { [Key_1 in import("../types/schema.js").OptionalKeysRead<S>]?: S[Key_1]["type"] | undefined; }> | undefined;
        } & import("../types/utils.js").FlattenTypes<import("./record.js").RecordProps<S>>>): DBRecordInstance<S, import("../types/query.js").SearchQuery<S>>;
        api: ReturnType<typeof import("../api/create-api.js").createApi>;
        fetcher: ReturnType<typeof import("../network/index.js").createFetcher>;
        records: import("../api/types.js").RecordsApi;
        relations: {
            find: <S extends Schema = any>({ pagination, search, transaction }: {
                pagination?: Pick<import("../types/query.js").SearchQuery, "limit" | "skip">;
                search?: import("../types/query.js").SearchQuery<S> | undefined;
                transaction?: import("./transaction.js").Transaction | string;
            }) => Promise<import("../index.node.js").ApiResponse<import("./record.js").Relation[]>>;
        };
        properties: {
            delete: (id: string, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property>>;
            find: <S extends Schema = any>(searchParams: import("../types/query.js").SearchQuery<S>, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property[]>>;
            findById: (id: string, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property>>;
            values: (id: string, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property & import("../types/value.js").PropertyValuesData>>;
        };
        labels: {
            find: <S extends Schema = any>(searchParams: import("../types/query.js").SearchQuery<S>, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<Record<string, number>>>;
        };
        tx: {
            begin: (config?: Partial<{
                ttl: number;
            }>) => Promise<import("./transaction.js").Transaction>;
            commit: (id: string) => Promise<import("../index.node.js").ApiResponse<{
                message: string;
            }>>;
            get: (id: string) => Promise<import("./transaction.js").Transaction>;
            rollback: (id: string) => Promise<import("../index.node.js").ApiResponse<{
                message: string;
            }>>;
        };
    };
    getInstance(): {
        state: State;
        models: Map<string, Model>;
        registerModel(model: Model): Model<any>;
        getModels(): Map<string, Model>;
        getModel<Label extends keyof Models | string = never>(label: Label): Label extends keyof Models ? Model<Models[Label]> : Model | undefined;
        toInstance<S extends Schema = Schema>(record: import("../types/utils.js").FlattenTypes<{
            readonly __id: string;
            readonly __label: string;
            readonly __proptypes?: import("../types/utils.js").FlattenTypes<{ [Key in import("../types/schema.js").RequiredKeysRead<S>]: S[Key]["type"]; } & { [Key_1 in import("../types/schema.js").OptionalKeysRead<S>]?: S[Key_1]["type"] | undefined; }> | undefined;
        } & import("../types/utils.js").FlattenTypes<import("./record.js").RecordProps<S>>>): DBRecordInstance<S, import("../types/query.js").SearchQuery<S>>;
        api: ReturnType<typeof import("../api/create-api.js").createApi>;
        fetcher: ReturnType<typeof import("../network/index.js").createFetcher>;
        records: import("../api/types.js").RecordsApi;
        relations: {
            find: <S extends Schema = any>({ pagination, search, transaction }: {
                pagination?: Pick<import("../types/query.js").SearchQuery, "limit" | "skip">;
                search?: import("../types/query.js").SearchQuery<S> | undefined;
                transaction?: import("./transaction.js").Transaction | string;
            }) => Promise<import("../index.node.js").ApiResponse<import("./record.js").Relation[]>>;
        };
        properties: {
            delete: (id: string, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property>>;
            find: <S extends Schema = any>(searchParams: import("../types/query.js").SearchQuery<S>, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property[]>>;
            findById: (id: string, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property>>;
            values: (id: string, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<import("../types/value.js").Property & import("../types/value.js").PropertyValuesData>>;
        };
        labels: {
            find: <S extends Schema = any>(searchParams: import("../types/query.js").SearchQuery<S>, transaction?: import("./transaction.js").Transaction | string) => Promise<import("../index.node.js").ApiResponse<Record<string, number>>>;
        };
        tx: {
            begin: (config?: Partial<{
                ttl: number;
            }>) => Promise<import("./transaction.js").Transaction>;
            commit: (id: string) => Promise<import("../index.node.js").ApiResponse<{
                message: string;
            }>>;
            get: (id: string) => Promise<import("./transaction.js").Transaction>;
            rollback: (id: string) => Promise<import("../index.node.js").ApiResponse<{
                message: string;
            }>>;
        };
    };
};
